@@ -64,6 +64,7 @@ static void do_free_callouts(struct ol_queue *q);
 struct callout
 {
 	struct ol_queue_node header;
+	int drop;
 	struct callback *callout;
 	time_t when;
 };
@@ -1285,6 +1286,7 @@ struct callout *io_callout(struct io_backend *backend, time_t timeout, struct ca
 	NEW_SPACE(co);
 	co->when = time(NULL) + timeout;
 	co->callout = callout;
+	co->drop = 1;
 	ol_queue_add_tail(&backend->callouts, &co->header);
 	return co;
 }
@@ -1294,6 +1296,21 @@ void io_callout_set_timeout(struct callout *co, time_t timeout)
 	co->when = time(NULL) + timeout;
 }
 
+void io_callout_set_drop(struct callout *co, int drop)
+{
+	co->drop = drop;
+}
+
+void io_callout_flush(struct io_backend *backend)
+{
+	FOR_QUEUE(&backend->callouts, struct callout *, n) {
+		if (!n->drop)
+			CALLBACK(n->callout);
+		ol_queue_remove(&n->header);
+		ol_space_free(n);
+	}
+
+}
 
 void kill_fd(struct nonblocking_fd *fd)
 {
