@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: io.h,v 1.7 1999/08/04 21:31:03 bazsi Exp $
+ * $Id: io.h,v 1.8 1999/11/22 18:26:24 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -269,8 +269,9 @@ struct io_fd *io_write(struct io_fd *fd,
 		       struct close_callback *close_callback);
 
 struct callout *io_callout(struct io_backend *backend, time_t timeout, struct callback *callout);
-
 void io_callout_set_timeout(struct callout *co, time_t timeout);
+void io_callout_set_drop(struct callout *co, int drop);
+void io_callout_flush(struct io_backend *backend);
 
 #define closekill_fd(fd, reason) close_fd(fd, reason), kill_fd(fd)
 
